% Lehrstuhlloesungsvorschlag fuers Bisektionsverfahren

% f: Funktion, deren Nullstelle gesucht werden soll
% a: Linke  Intervallgrenze
% b: Rechte Intervallgrenze
function [x,k] = bisektion(f,a,b,tol)

if f(a)*f(b) > 0
    error('Unpassende Werte a und b.');
end

k = 0;

while abs(b-a) >= tol
    
    k = k+1;
    x = (a+b)/2;
    
    if f(x)*f(a) > 0
        a = x;
    else
        b = x;
    end
end
